Date: 01 4, 2002 11:14:41 AM

# fileout

## Purpose

Open fileName for appending. FileName becomes a variable useable in print actions with a file argument, e.g. prlit().

## Syntax

fileout(fileName)

fileName - type: str

## Returns

## Remarks

Old-style. Use NLP++ syntax such as

"file.txt" << "hello\n";

to create files in the current output area. Or, use openfile to place files anywhere on your file system.

## Example

## See Also

openfile, startout, stopout, prlit, CODE Actions